@@ -8,10 +8,11 @@
 
 using namespace Rcpp;
 
-IntegerMatrix get_nb_coords(IntegerMatrix mat, 
-                            std::pair<int,int> X,
-                            IntegerMatrix nbmask, 
-                            bool wrap);
+std::queue <std::pair<int, int> > get_nb_coords(const int W, // width
+                                                const int H, // height
+                                                const std::pair<int,int> X,
+                                                const IntegerMatrix& nbmask, 
+                                                const bool wrap); 
 
 IntegerVector flood_fill(const IntegerMatrix &mat, 
                          LogicalMatrix &is_marked,
@@ -21,7 +22,7 @@ IntegerVector flood_fill(const IntegerMatrix &mat,
                          int fillcol,
                          bool wrap);
 
-Rcpp::NumericMatrix coarse_grain(NumericMatrix mat, 
-                                 int subsize);
+NumericMatrix coarse_grain(NumericMatrix mat, 
+                           int subsize);
 
 #endif
